"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["7176"],{62900:function(e,n,t){t.r(n);var r=t(91942),u=t(81556),a=t(46413),o=t(1975);n.default=function(){var e=(0,r.useTranslation)().t;return o.createElement(u.E,{message:e(a.E),title:e(a.W)})}},46413:function(e,n,t){t.d(n,{E:function(){return r},W:function(){return u}});var r="You are not allowed to see this page",u="Lost in space?"}}]);
//# sourceMappingURL=7176.59260f85c57b70ed7c27.ebfcfb56f48c6766e61b.6f0d4805c7bd876f6031.js.map