"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["6832"],{99937:function(e,n,t){t.r(n);var o=t(92229),r=t(26143),a=t(1975),i=(0,r.Z)({Component:function(e){var n=e.options,t=e.selectedOptionId,r=e.onChange,i=e.ariaLabel;return a.createElement(o.Z,{"aria-label":i,"data-testid":"selectedFilter",options:n,selectedOptionId:t,onChange:r})},memoProps:["options","selectedOptionId"]});n.default=i},26143:function(e,n,t){var o=t(1975),r=t(16451),a=t(34018);n.Z=function(e){var n=e.memoProps,t=e.Component;return(0,o.memo)(t,function(e,t){return(0,r.Z)((0,a.Z)(n,e),(0,a.Z)(n,t))})}}}]);
//# sourceMappingURL=6832.89b96e059d5577c100ab.f1714669ae4ca3d5714b.6f0d4805c7bd876f6031.js.map