"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["9181"],{79066:function(e,n,t){t.r(n);var a=t(9826),r=t(48065),c=t(41619),i=t(91942),o=t(87146),l=t(51688),u=t(78653),s=t(80509),f=t(32516),d=t(1975),p=(0,o.ZL)()(function(e){return{otherProvidersContainer:{display:"flex",flexDirection:"column",marginTop:e.spacing(1),rowGap:e.spacing(1),width:"100%"}}});n.default=function(e){var n=e.providersConfiguration,t=p().classes,o=(0,i.useTranslation)().t;return(0,a.Z)((0,r.Z)(n),(0,c.Z)(n))?null:d.createElement("div",{className:t.otherProvidersContainer},d.createElement(l.Z,null,d.createElement(u.Z,null,o(f.Ef))),null==n?void 0:n.map(function(e){var n=e.name,t=e.authenticationUri,a="".concat(f.A2," ").concat(n),r="".concat(o(f.A2)," ").concat(n);return d.createElement(s.Z,{"aria-label":r,color:"primary","data-testid":a,href:t,key:n,variant:"contained"},r)}))}}}]);
//# sourceMappingURL=9181.2710977bed72b39838ee.0416a3cc3c83e1facfb2.6f0d4805c7bd876f6031.js.map