"use strict";(self.webpackChunkcentreon=self.webpackChunkcentreon||[]).push([["4904"],{80170:function(e,t,n){var r=n(88619);t.default=void 0;var a=r(n(14420)),l=n(52676);t.default=(0,a.default)((0,l.jsx)("path",{d:"M6 19h4V5H6zm8-14v14h4V5z"}),"Pause")},80339:function(e,t,n){var r=n(88619);t.default=void 0;var a=r(n(14420)),l=n(52676);t.default=(0,a.default)((0,l.jsx)("path",{d:"M8 5v14l11-7z"}),"PlayArrow")},65968:function(e,t,n){var r=n(88619);t.default=void 0;var a=r(n(14420)),l=n(52676);t.default=(0,a.default)((0,l.jsx)("path",{d:"M17.65 6.35C16.2 4.9 14.21 4 12 4c-4.42 0-7.99 3.58-7.99 8s3.57 8 7.99 8c3.73 0 6.84-2.55 7.73-6h-2.08c-.82 2.33-3.04 4-5.65 4-3.31 0-6-2.69-6-6s2.69-6 6-6c1.66 0 3.14.69 4.22 1.78L13 11h7V4z"}),"Refresh")},23247:function(e,t,n){n.r(t);var r=n(26017),a=n(91942),l=n(80170),i=n(80339),o=n(65968),u=n(21049),c=n(92140),s=n(43750),f=n(51883),d=n(6766),m=n(70231),h=n(1975);function v(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}var b=function(e){var t=e.enabledAutorefresh,n=e.toggleAutorefresh,r=(0,a.useTranslation)().t,o=t?f.B21:f.mhU;return h.createElement(c.Z,{ariaLabel:r(o),"data-testid":"Disable autorefresh",size:"small",title:r(o),onClick:n},t?h.createElement(l.default,null):h.createElement(i.default,null))};t.default=function(e){var t,n,l=e.onRefresh,i=e.displayAsIcons,p=e.displayAsList,y=(0,m.y)().classes,A=(0,a.useTranslation)().t;var E=(t=(0,r.useAtom)(s.Op),n=2,function(e){if(Array.isArray(e))return e}(t)||function(e,t){var n,r,a=null==e?null:"undefined"!=typeof Symbol&&e[Symbol.iterator]||e["@@iterator"];if(null!=a){var l=[],i=!0,o=!1;try{for(a=a.call(e);!(i=(n=a.next()).done)&&(l.push(n.value),!t||l.length!==t);i=!0);}catch(e){o=!0,r=e}finally{try{!i&&null!=a.return&&a.return()}finally{if(o)throw r}}return l}}(t,2)||function(e,t){if(e){if("string"==typeof e)return v(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if("Object"===n&&e.constructor&&(n=e.constructor.name),"Map"===n||"Set"===n)return Array.from(n);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return v(e,t)}}(t,n)||function(){throw TypeError("Invalid attempt to destructure non-iterable instance.\\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}()),g=E[0],Z=E[1],k=(0,r.useAtomValue)(s.zz),C=function(){Z(!g)};return h.createElement(h.Fragment,null,(void 0===i||i)&&h.createElement(u.ZP,{container:!0,className:y.container},h.createElement(u.ZP,{item:!0},h.createElement(c.Z,{ariaLabel:A(f.nj5),"data-testid":"Refresh",disabled:k,size:"small",title:A(f.nj5),onClick:l},h.createElement(o.default,null))),h.createElement(u.ZP,{item:!0},h.createElement(b,{enabledAutorefresh:g,toggleAutorefresh:C}))),(null==p?void 0:p.display)&&h.createElement(h.Fragment,null,h.createElement(d.Z,{permitted:!0,disabled:!1,label:f.nj5,testId:"RefreshInMoreActions",onClick:function(){l(),p.close()}}),h.createElement(d.Z,{permitted:!0,disabled:!1,label:g?f.B21:f.mhU,testId:"AutorefreshInMoreActions",onClick:function(){C(),p.close()}})))}},70231:function(e,t,n){n.d(t,{y:function(){return r}});var r=(0,n(87146).ZL)()({container:{flexWrap:"nowrap"}})},6766:function(e,t,n){var r=n(91942),a=n(22833),l=n(95139),i=n(51883),o=n(1975);t.Z=function(e){var t=e.permitted,n=e.label,u=e.testId,c=e.onClick,s=e.disabled,f=(0,r.useTranslation)().t,d=t?"":f(i.x6i);return o.createElement(a.Z,{title:d},o.createElement("div",null,o.createElement(l.Z,{"data-testid":u,disabled:s,onClick:c},f(n))))}}}]);
//# sourceMappingURL=4904.a90829f6eb59b5626aa1.21ea61b25be2eb970b57.6f0d4805c7bd876f6031.js.map